@@ -1,10 +1,12 @@
-require "tomlrb/generated_parser"
+# frozen-string-literal: true
+
+require 'tomlrb/generated_parser'
 
 class Tomlrb::Parser < Tomlrb::GeneratedParser
 
   def initialize(tokenizer, **options)
     @tokenizer = tokenizer
-    @handler   = Tomlrb::Handler.new(options)
+    @handler   = Tomlrb::Handler.new(**options)
     super()
   end
 
